<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>WindowSelectionGrid</name>
    <message>
        <location filename="../qml/WindowSelectionGrid.qml" line="455"/>
        <source>No windows</source>
        <translation>无打开的窗口</translation>
    </message>
</context>
<context>
    <name>WorkspaceSelectionList</name>
    <message>
        <location filename="../qml/WorkspaceSelectionList.qml" line="99"/>
        <source>Release to delete</source>
        <translation>释放以删除</translation>
    </message>
</context>
</TS>